==> twlog_1.2.orig.tar.gz: twlog-1.2.orig/savedir/twlog.h <==
/*
 * TWLOG.H  
 * Versions: 1.2 -  Nov 1998
 */

/*
 * INCLUDES AND DEFINES
 */

#include <time.h>
#include <errno.h>
#include <stdio.h>
#include <errno.h>
#include <ctype.h>
#include <fcntl.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/types.h>

#include <Xm/Form.h>
#include <Xm/Text.h>
#include <Xm/PushB.h>
#include <Xm/Label.h>
#include <Xm/TextF.h>
#include <Xm/MwmUtil.h>
#include <Xm/DialogS.h>
#include <Xm/MessageB.h> 
#include <Xm/MenuShell.h>
#include <Xm/RowColumn.h>
#include <Xm/Separator.h>
#include <X11/StringDefs.h>
#include <X11/xpm.h>

#define XS_CONVERT( property, value ) \
           XtVaTypedArg, (property), XmRString, (value), strlen(value) + 1

#define MAXNAME    25
#define LOGFILE   "logfile"
#define HELPFILE  "helpfile"
#define PRINT_CMD "lpr "


#define NUMCOLS    11
#define MAXNAME    25

/*
 * APPLICATION DEFINED RESOURCES 
 */

#define XmNdirpath         "dirpath"
#define XmCDirpath         "Dirpath"

#define XmNtzone           "tzone"
#define XmCTzone           "Tzone"
 
#define XmNbands           "bands"
#define XmCBands           "Bands"
#define XmNdefault_band    "default_band"
#define XmCDefault_band    "Default_band"

#define XmNmodes           "modes"
#define XmCModes           "Modes"
#define XmNdefault_mode    "default_mode"
#define XmCDefault_mode    "Default_mode"

#define XmNpower           "power"
#define XmCPower           "Power"
#define XmNdefault_power   "default_power"
#define XmCDefault_power   "Default_power"

typedef struct
           {
           char            *dirpath;
           int             tzone;
           XmStringTable   bands;
           int             default_band;
           XmStringTable   modes;
           int             default_mode;
           XmStringTable   power;
           int             default_power;
           } LogRes;

typedef struct 
           {
           Widget TF1;
           Widget TF2;
           Widget next;
           } Cdata;
/*
 * GLOBALS
 */

Widget logSH;
char *dirpath;
char *logpath;
char *helppath;

/*
 * FUNCTION DECLARATIONS
 */

void build_widgets (Widget w, LogRes app_data);
void dateCB (Widget w, XtPointer cdata, XtPointer cbs);
void startCB (Widget w, XtPointer cdata, XtPointer cbs);
void callsignCB (Widget w, XtPointer cdata, XtPointer cbs);
void endCB (Widget w, XtPointer cdata, XtPointer cbs);
void fileCB (Widget w, XtPointer cdata, XtPointer cbs);
void helpCB (Widget w, XtPointer cdata, XtPointer cbs);
void focusCB (Widget w, XtPointer cdata, XtPointer cbs);
void CRkey (Widget w, XEvent *event, String args[], Cardinal *nargs);
void diagCB (Widget w, XtPointer cdata, XtPointer cbs);
void okCB (Widget w, XtPointer cdata, XtPointer cbs);
void saveCB (Widget w, XtPointer cdata, XtPointer cbs);
void searchCB (Widget w, XtPointer cdata, XtPointer cbs);
void appendlog (char logpath[], Widget *col_2_wids);
void clearform (Widget *col_2_wids);
void popupEdit (char *filename);
void popupHelp (char *filename);
void getdata (char *filename, Widget wid);
void aboutDiag (void);
int  putenv (char *);

==> twlog_1.3.orig.tar.gz: twlog-1.3.orig/savedir/twlog.h <==
/*
 * TWLOG.H  
 * Versions: 1.3 -  Feb 2001
 */

/*
 * INCLUDES AND DEFINES
 */

#include <time.h>
#include <errno.h>
#include <stdio.h>
#include <errno.h>
#include <ctype.h>
#include <fcntl.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/types.h>

#include <Xm/Form.h>
#include <Xm/Text.h>
#include <Xm/PushB.h>
#include <Xm/Label.h>
#include <Xm/TextF.h>
#include <Xm/MwmUtil.h>
#include <Xm/DialogS.h>
#include <Xm/MessageB.h> 
#include <Xm/MenuShell.h>
#include <Xm/RowColumn.h>
#include <Xm/Separator.h>
#include <X11/StringDefs.h>
#include <X11/xpm.h>

#define XS_CONVERT( property, value ) \
           XtVaTypedArg, (property), XmRString, (value), strlen(value) + 1

#define MAXNAME    25
#define LOGFILE   "logfile"
#define HELPFILE  "twlogHelp"
#define PRINT_CMD "lpr "
#define NUMCOLS    6 

/*
 * APPLICATION DEFINED RESOURCES 
 */

#define XmNdirpath         "dirpath"
#define XmCDirpath         "Dirpath"

#define XmNtzone           "tzone"
#define XmCTzone           "Tzone"
 
#define XmNbands           "bands"
#define XmCBands           "Bands"
#define XmNdefault_band    "default_band"
#define XmCDefault_band    "Default_band"

#define XmNmodes           "modes"
#define XmCModes           "Modes"
#define XmNdefault_mode    "default_mode"
#define XmCDefault_mode    "Default_mode"

#define XmNpower           "power"
#define XmCPower           "Power"
#define XmNdefault_power   "default_power"
#define XmCDefault_power   "Default_power"

typedef struct
           {
           char            *dirpath;
           int             tzone;
           XmStringTable   bands;
           int             default_band;
           XmStringTable   modes;
           int             default_mode;
           XmStringTable   power;
           int             default_power;
           } LogRes;

typedef struct 
           {
           Widget TF1;
           Widget TF2;
           Widget next;
           } Cdata;
/*
 * GLOBALS
 */

Widget logSH;
char *dirpath;
char *logpath;
char *helppath;

/*
 * FUNCTION DECLARATIONS
 */

void build_widgets (Widget w, LogRes app_data);
Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelXS);
void dateCB (Widget w, XtPointer cdata, XtPointer cbs);
void startCB (Widget w, XtPointer cdata, XtPointer cbs);
void callsignCB (Widget w, XtPointer cdata, XtPointer cbs);
void traverseCB (Widget w, XtPointer cdata, XtPointer cbs);
void endCB (Widget w, XtPointer cdata, XtPointer cbs);
void fileCB (Widget w, XtPointer cdata, XtPointer cbs);
void helpCB (Widget w, XtPointer cdata, XtPointer cbs);
void focusCB (Widget w, XtPointer cdata, XtPointer cbs);
void CRkey (Widget w, XEvent *event, String args[], Cardinal *nargs);
void diagCB (Widget w, XtPointer cdata, XtPointer cbs);
void okCB (Widget w, XtPointer cdata, XtPointer cbs);
void saveCB (Widget w, XtPointer cdata, XtPointer cbs);
void searchCB (Widget w, XtPointer cdata, XtPointer cbs);
void appendlog (char logpath[], Widget *col_2_wids);
void clearform (Widget *col_2_wids);
void popupEdit (char *filename);
void popupHelp (char *filename);
void getdata (char *filename, Widget wid);
void aboutDiag (void);
/* int  putenv (char *); */
